Stan Math Library: stan::math::precomp_vv_vari Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Protected Attributes | List of all members
stan::math::precomp_vv_vari Class Reference

`#include <precomp_vv_vari.hpp>`

Inheritance diagram for stan::math::precomp_vv_vari:

## Public Member Functions
| precomp_vv_vari (double val, vari *avi, vari *bvi, double da, double db)
void | chain ()
| Apply the chain rule to this variable based on the variables on which it depends. More...
Public Member Functions inherited from stan::math::op_vv_vari
| op_vv_vari (double f, vari *avi, vari *bvi)
Public Member Functions inherited from stan::math::vari
| vari (const double x)
| Construct a variable implementation from a value. More...
| vari (const double x, bool stacked)
virtual | ~vari ()
| Throw an illegal argument exception. More...
void | init_dependent ()
| Initialize the adjoint for this (dependent) variable to 1. More...
void | set_zero_adjoint ()
| Set the adjoint value of this variable to 0. More...

## Protected Attributes
double | da_
double | db_
Protected Attributes inherited from stan::math::op_vv_vari
vari * | avi_
vari * | bvi_

## Additional Inherited Members
Static Public Member Functions inherited from stan::math::vari
static void * | operator new (size_t nbytes)
| Allocate memory from the underlying memory pool. More...
static void | operator delete (void *)
| Delete a pointer from the underlying memory pool. More...
Public Attributes inherited from stan::math::vari
const double | val_
| The value of this variable. More...
double | adj_
| The adjoint of this variable, which is the partial derivative of this variable with respect to the root variable. More...

## Detailed Description

Definition at line 11 of file precomp_vv_vari.hpp.

## Constructor & Destructor Documentation

stan::math::precomp_vv_vari::precomp_vv_vari | ( | double | val,
|  | vari * | avi,
|  | vari * | bvi,
|  | double | da,
|  | double | db
| ) |  |
| inline

Definition at line 16 of file precomp_vv_vari.hpp.

## Member Function Documentation

void stan::math::precomp_vv_vari::chain | ( |  | ) |
| inlinevirtual

Apply the chain rule to this variable based on the variables on which it depends.

The base implementation in this class is a no-op.

Reimplemented from stan::math::vari.

Definition at line 23 of file precomp_vv_vari.hpp.

## Member Data Documentation

double stan::math::precomp_vv_vari::da_
| protected

Definition at line 13 of file precomp_vv_vari.hpp.

double stan::math::precomp_vv_vari::db_
| protected

Definition at line 14 of file precomp_vv_vari.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/core/precomp_vv_vari.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.